# binarize2pcalcium
Binarization pipelines for converting continuous 2P calcium imaging traces into binarized time series

# Basic use

from binarize2pcalcium.utils import calcium

c = calcium.Calcium(data_dir, animal_id)

